/**
  ******************************************************************************
  * @file    stm32f0xx_it.c
  * @author  Ac6
  * @version V1.0
  * @date    02-Feb-2015
  * @brief   Default Interrupt Service Routines.
  ******************************************************************************
*/

/* Includes ------------------------------------------------------------------*/
#include "stm32f0xx_hal.h"
#include "stm32f0xx.h"
#ifdef USE_RTOS_SYSTICK
#include <cmsis_os.h>
#endif
#include "stm32f0xx_it.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/******************************************************************************/
/*            	  	    Processor Exceptions Handlers                         */
/******************************************************************************/

/**
  * @brief  This function handles SysTick Handler, but only if no RTOS defines it.
  * @param  None
  * @retval None
  */
void SysTick_Handler(void)
{
	HAL_IncTick();
	HAL_SYSTICK_IRQHandler();
#ifdef USE_RTOS_SYSTICK
	osSystickHandler();
#endif
}

volatile uint32_t* tim_cr1 = &(TIM1->CR1);
void TIM14_IRQHandler(void) {
	// This can be commented out, since update is the only source of interrupt
	if(TIM14->SR & TIM_SR_UIF) {
		TIM14->SR &= ~TIM_SR_UIF; // clear UIF flag

		if (tim_cr1 > 0) {
			*tim_cr1 |= TIM_CR1_CEN;

			// Set the next timer to be enabled
			if (tim_cr1 == &(TIM1->CR1)) {
				tim_cr1 = &(TIM16->CR1);
			} else if (tim_cr1 == &(TIM16->CR1)) {
				tim_cr1 = &(TIM17->CR1);
			} else if (tim_cr1 == &(TIM17->CR1)) {
				// All timers have been synchronized to the correct phase order
				tim_cr1 = 0;	// No more CR1 to be set

				// Disable the timer
				TIM14->CR1 &=~ TIM_CR1_CEN;
			}
		} else {
			// Execute control routine here
		}
	} // if(TIM14->SR & TIM_SR_UIF)
}
